@@ -20,7 +20,7 @@ my $refiddoc=	$ARGV[1] || 0;
 my $lot	= 	$ARGV[2] || 0;
 
 my $cfg = config_read('EDTK_STATS');
-my $dbh = db_connect($cfg, 'EDTK_DSN_STATS',
+my $dbh = db_connect($cfg, 'EDTK_DBI_STATS',
     { AutoCommit => 1, RaiseError => 1 });
 
 
